<template>
  <!-- 搜索工作栏 -->
  <ContentWrap>
    <el-form
      class="-mb-15px"
      :model="queryParams"
      ref="queryFormRef"
      :inline="true"
      label-width="68px"
    >
      <el-form-item label="模型名称" prop="iconName">
        <el-input
          v-model="queryParams.iconName"
          placeholder="请输入名称"
          clearable
          class="!w-240px"
        />
      </el-form-item>
      <el-form-item>
        <el-button @click="handleQuery">
          <Icon icon="ep:search" class="mr-5px"/>
          搜索
        </el-button>
        <el-button @click="resetQuery">
          <Icon icon="ep:refresh" class="mr-5px"/>
          重置
        </el-button>
        <el-button
          type="primary"
          plain
          @click="openForm('create')"
          v-hasPermi="['mpk:menu:create']"
        >
          <Icon icon="ep:plus" class="mr-5px" />
          新增
        </el-button>

      </el-form-item>
    </el-form>
  </ContentWrap>

  <!-- 列表 -->
  <ContentWrap>
    <el-table
      v-loading="loading"
      :data="list"
      row-key="id"
    >
      <el-table-column prop="name" label="名称"/>
      <el-table-column prop="sort" label="排序"/>
      <el-table-column label="操作" align="center" width="200px">
        <template #default="scope">
          <div class="flex items-center justify-center">
            <el-button
              link
              type="primary"
              @click="openForm('update', scope.row.id)"
              v-hasPermi="['mpk:menu:update']"
            >
              编辑
            </el-button>
            <el-button
              link
              type="primary"
              @click="openGroupList(scope.row.id)"
              v-hasPermi="['mpk:menu:update']"
            >
              分组
            </el-button>
            <el-button link type="danger" @click="handleDelete(scope.row.id)" v-hasPermi="['mpk:menu:delete']">
              <Icon icon="ep:delete"/>删除
            </el-button>
          </div>
        </template>
      </el-table-column>
    </el-table>
  </ContentWrap>

  <!-- 表单弹窗：添加/修改 -->
  <MenuForm ref="formRef" @success="getList" />

  <!-- 分组列表 -->
  <GroupList ref="listRef" />

</template>
<script lang="ts" setup>
import {dateFormatter} from '@/utils/formatTime'
import * as MpkMenuApi from '@/api/model/mpk/menu'
import MenuForm from './MenuForm.vue'
import GroupList from './group/index.vue'

defineOptions({name: 'MpkMenu'})

const message = useMessage() // 消息弹窗
const {t} = useI18n() // 国际化

const loading = ref(true) // 列表的加载中
const list = ref([]) // 字典表格数据
const queryParams = reactive({
  name: ''
})
const queryFormRef = ref() // 搜索的表单

const getList = async () => {
  loading.value = true
  try {
    const data = await MpkMenuApi.getList(queryParams)
    list.value = data.list
  } finally {
    loading.value = false
  }
}

/** 搜索按钮操作 */
const handleQuery = () => {
  getList()
}

/** 重置按钮操作 */
const resetQuery = () => {
  queryFormRef.value.resetFields()
  handleQuery()
}

/** 添加/修改操作 */
const formRef = ref()
const openForm = (type: string, id?: string) => {
  formRef.value.open(type, id)
}

/** 删除按钮操作 */
const handleDelete = async (id: string) => {
  try {
    // 删除的二次确认
    await message.delConfirm()
    // 发起删除
    await MpkMenuApi.deleteMenu(id)
    message.success(t('common.delSuccess'))
    // 刷新列表
    await getList()
  } catch {
  }
}

/** List操作 */
const listRef = ref()
const openGroupList = (id?: string) => {
  listRef.value.open(id)
}

/** 初始化 **/
onMounted(async () => {
  await getList()
})
</script>
